pg_column_type

Function pg_column_type 

pub fn pg_column_type(ty: FieldType) -> &'static str
The Postgres column type for a Gize field type. Single source of truth reused by the migration templates.